searchNodes=[{"ref":"ExNist.html","title":"ExNist","type":"module","doc":"Set of Ecto.Changeset functions to validate against NIST guidelines. Modeled after laravel-nist-password-rules RecommendationImplementation [...] at least 8 characters in lengthProvided by standard Ecto.Changeset validation function Passwords obtained from previous breach corpusesThe ExNist.validate_password_breach/3 function securely checks the password against previous 3rd party data breaches, using the Have I Been Pwned - Pwned Passwords API. Dictionary wordsThe ExNist.validate_dictionary_words/3 rule checks the password against a list of over 102k dictionary words. Context-specific words, such as the name of the service, the usernameThe ExNist.validate_context_specific_words/3 rule checks the password does not contain the provided list of words. Context-specific words, [...] and derivatives thereofThe ExNist.validate_derivative_words/3 rule checks the password is not too similar to the provided list of words. Repetitive or sequential characters (e.g. ‘aaaaaa’, ‘1234abcd’)The ExNist.validate_repetitive_chars/3 and ExNist.validate_sequential_chars/3 rules checks if the password contains any repetitive or sequential characters. Installation The package can be installed by adding ex_nist to your list of dependencies in mix.exs: def deps do [ {:ex_nist, &quot;~&gt; 1.0.0&quot;}, # Optionally add `ex_pwned` # {:ex_pwned, &quot;~&gt; 0.1.4&quot;} ] end The library can use the ExPwned or you can implement your own client. To use ExPwned, add it to your mix.exs Usage Use in a function to validate changesets. def changeset(user, attrs) do user |&gt; ExNist.validate_repetitive_chars(:password) |&gt; ExNist.validate_sequential_chars(:password) |&gt; ExNist.validate_context_specific_words(:password, [&quot;name_of_app&quot;]) |&gt; ExNist.validate_derivative_words(:password, [&quot;name_of_app&quot;]) |&gt; ExNist.validate_dictionary_words(:password) |&gt; ExNist.validate_password_breach(:password) end The validation_* functions accept an optional :message argument to customize the error message. Docs Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/ex_nist."},{"ref":"ExNist.html#validate_context_specific_words/3","title":"ExNist.validate_context_specific_words/3","type":"function","doc":"Validate a changeset field for the use of context specific words. E.g. supply a list with words containing the username and the application name. Examples iex&gt; ExNist.validate_context_specific_words(build_changeset(&quot;abc&quot;), :password, words: [&quot;abc&quot;]) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;abc&quot;}, errors: [password: {&quot;This password contains disallowed words&quot;, []}], data: %{}, valid?: false&gt; iex&gt; ExNist.validate_context_specific_words(build_changeset(&quot;aab&quot;), :password, words: [&quot;abc&quot;]) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;aab&quot;}, errors: [], data: %{}, valid?: true&gt;"},{"ref":"ExNist.html#validate_derivative_words/3","title":"ExNist.validate_derivative_words/3","type":"function","doc":"Validate a changeset field for the use of derivative words of a supplied list of words. E.g. supply a list with words containing the username and the application name. Examples iex&gt; ExNist.validate_derivative_words(build_changeset(&quot;abc&quot;), :password, words: [&quot;bbc&quot;]) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;abc&quot;}, errors: [password: {&quot;This password contains derivative disallowed words&quot;, [word: &quot;bbc&quot;]}], data: %{}, valid?: false&gt; iex&gt; ExNist.validate_derivative_words(build_changeset(&quot;abcdef&quot;), :password, words: [&quot;bbcdef&quot;], similarity_percentage: 0.90) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;abcdef&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; ExNist.validate_derivative_words(build_changeset(&quot;aab&quot;), :password, words: [&quot;abc&quot;]) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;aab&quot;}, errors: [], data: %{}, valid?: true&gt;"},{"ref":"ExNist.html#validate_dictionary_words/3","title":"ExNist.validate_dictionary_words/3","type":"function","doc":"Validate a changeset field for the use of common words in a dictionary file. Examples iex&gt; ExNist.validate_dictionary_words(build_changeset(&quot;Baker&quot;), :password, words: [&quot;bbc&quot;]) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;Baker&quot;}, errors: [password: {&quot;This password contains disallowed words&quot;, [word: &quot;baker&quot;]}], data: %{}, valid?: false&gt; iex&gt; ExNist.validate_dictionary_words(build_changeset(&quot;abcdef&quot;), :password, words: [&quot;bbcdef&quot;]) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;abcdef&quot;}, errors: [], data: %{}, valid?: true&gt;"},{"ref":"ExNist.html#validate_password_breach/3","title":"ExNist.validate_password_breach/3","type":"function","doc":"Validate a changeset field for the use of common words in a dictionary file. The opts accepts :password_breach_client , it defaults to ExNist.PasswordBreachClient.ExPwned but can be another module that implements the ExNist.PasswordBreachClient behaviour. Examples ExNist.validate_password_breach(build_changeset(&quot;secret&quot;), :password) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;Baker&quot;}, errors: [password: {&quot;This password has appeared in a data breach.&quot;, [num_breaches: 5]}], data: %{}, valid?: false&gt; ExNist.validate_password_breach(build_changeset(&quot;lkjlkjsda2dfs9234&quot;), :password) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;abcdef&quot;}, errors: [], data: %{}, valid?: true&gt;"},{"ref":"ExNist.html#validate_repetitive_chars/3","title":"ExNist.validate_repetitive_chars/3","type":"function","doc":"Validate a changeset field for the use of repetitive characters Examples iex&gt; ExNist.validate_repetitive_chars(build_changeset(&quot;aaab&quot;), :password) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;aaab&quot;}, errors: [password: {&quot;This password has the same character repeated&quot;, [validation: :repeated_character]}], data: %{}, valid?: false&gt; iex&gt; ExNist.validate_repetitive_chars(build_changeset(&quot;aab&quot;), :password) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;aab&quot;}, errors: [], data: %{}, valid?: true&gt;"},{"ref":"ExNist.html#validate_sequential_chars/3","title":"ExNist.validate_sequential_chars/3","type":"function","doc":"Validate a changeset field for the use of sequences Examples iex&gt; ExNist.validate_sequential_chars(build_changeset(&quot;abc&quot;), :password) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;abc&quot;}, errors: [password: {&quot;This password contains a sequence (e.g. abc or 123)&quot;, []}], data: %{}, valid?: false&gt; iex&gt; ExNist.validate_sequential_chars(build_changeset(&quot;aab&quot;), :password) #Ecto.Changeset&lt;action: nil, changes: %{password: &quot;aab&quot;}, errors: [], data: %{}, valid?: true&gt;"},{"ref":"ExNist.PasswordBreachClient.html","title":"ExNist.PasswordBreachClient","type":"behaviour","doc":"Behaviour for a password breach client Clients should implement the password_breach_count/1 callback."},{"ref":"ExNist.PasswordBreachClient.html#c:password_breach_count/1","title":"ExNist.PasswordBreachClient.password_breach_count/1","type":"callback","doc":""},{"ref":"ExNist.PasswordBreachClient.ExPwned.html","title":"ExNist.PasswordBreachClient.ExPwned","type":"module","doc":"PasswordBreachClient for haveibeenpwned.com that uses the ExPwned library. See https://hex.pm/packages/ex_pwned"},{"ref":"ExNist.PasswordBreachClient.Test.html","title":"ExNist.PasswordBreachClient.Test","type":"module","doc":"Module to test with external breach detection BreachClient.Test.start_link({&quot;abc&quot;, 5}) build_changeset(&quot;abc&quot;) |&gt; ExNist.validate_password_breach(:password, breach_client: BreachClient.Test)"},{"ref":"ExNist.PasswordBreachClient.Test.html#child_spec/1","title":"ExNist.PasswordBreachClient.Test.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"ExNist.PasswordBreachClient.Test.html#password_breach_count/1","title":"ExNist.PasswordBreachClient.Test.password_breach_count/1","type":"function","doc":"Callback implementation for ExNist.PasswordBreachClient.password_breach_count/1."},{"ref":"ExNist.PasswordBreachClient.Test.html#start_link/1","title":"ExNist.PasswordBreachClient.Test.start_link/1","type":"function","doc":""},{"ref":"ExNist.Sequence.html","title":"ExNist.Sequence","type":"module","doc":"Module to generate list of sequences that passwords should not contain E.g. &quot;abc&quot;, &quot;cba&quot;, &quot;123&quot;"},{"ref":"ExNist.Sequence.html#build_sequence/2","title":"ExNist.Sequence.build_sequence/2","type":"function","doc":""},{"ref":"ExNist.Sequence.html#sequences/0","title":"ExNist.Sequence.sequences/0","type":"function","doc":"Returns list of sequences"},{"ref":"readme.html","title":"ExNist","type":"extras","doc":"ExNist Set of Ecto.Changeset functions to validate against NIST guidelines. Modeled after laravel-nist-password-rules RecommendationImplementation [...] at least 8 characters in lengthProvided by standard Ecto.Changeset validation function Passwords obtained from previous breach corpusesThe ExNist.validate_password_breach/3 function securely checks the password against previous 3rd party data breaches, using the Have I Been Pwned - Pwned Passwords API. Dictionary wordsThe ExNist.validate_dictionary_words/3 rule checks the password against a list of over 102k dictionary words. Context-specific words, such as the name of the service, the usernameThe ExNist.validate_context_specific_words/3 rule checks the password does not contain the provided list of words. Context-specific words, [...] and derivatives thereofThe ExNist.validate_derivative_words/3 rule checks the password is not too similar to the provided list of words. Repetitive or sequential characters (e.g. ‘aaaaaa’, ‘1234abcd’)The ExNist.validate_repetitive_chars/3 and ExNist.validate_sequential_chars/3 rules checks if the password contains any repetitive or sequential characters."},{"ref":"readme.html#installation","title":"ExNist - Installation","type":"extras","doc":"The package can be installed by adding ex_nist to your list of dependencies in mix.exs: def deps do [ {:ex_nist, &quot;~&gt; 1.0.0&quot;}, # Optionally add `ex_pwned` # {:ex_pwned, &quot;~&gt; 0.1.4&quot;} ] end The library can use the ExPwned or you can implement your own client. To use ExPwned, add it to your mix.exs"},{"ref":"readme.html#usage","title":"ExNist - Usage","type":"extras","doc":"Use in a function to validate changesets. def changeset(user, attrs) do user |&gt; ExNist.validate_repetitive_chars(:password) |&gt; ExNist.validate_sequential_chars(:password) |&gt; ExNist.validate_context_specific_words(:password, [&quot;name_of_app&quot;]) |&gt; ExNist.validate_derivative_words(:password, [&quot;name_of_app&quot;]) |&gt; ExNist.validate_dictionary_words(:password) |&gt; ExNist.validate_password_breach(:password) end The validation_* functions accept an optional :message argument to customize the error message."},{"ref":"readme.html#docs","title":"ExNist - Docs","type":"extras","doc":"Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/ex_nist."}]